fn load_rules_from_bv(bv: &BV) -> Option<Vec<FilterRule>>Expand description
Load a vector of rules from a value.
This first checks that the value is a block. If so, it loads a Vec of FilterRules.
fn load_rules_from_bv(bv: &BV) -> Option<Vec<FilterRule>>Load a vector of rules from a value.
This first checks that the value is a block. If so, it loads a Vec of FilterRules.